@ECHO OFF
ECHO OFF
GOTO Begin
REM
REM     Program          :  StrUtil.bat
REM
REM     Version          :  1.31
REM     Started on       :  November 24, 2007
REM     Completed on     :  November 24, 2007
REM
REM     Description      :  Library for string manipulation
REM
REM     Required modules :  Str2Env.exe, StrKeep.exe, StrLen.exe, StrSub.exe,
REM                         Grep.exe, FileUtil.bat
REM     Dos required     :  Dos 6.0 or later
REM
REM     Notes - usage    :  See help (/? parameter)
REM                         Setting SU_DEBUG environment variable to "Y", enable
REM                         on-screen commands echoing
REM                         Setting DEBUG environment variable to "Y", enable
REM                         on-screen commands echoing on return to caller
REM     References       :  None
REM
REM     Authors          :  J.Hubb - planning
REM                         J.Hubb - programming
REM                         J.Hubb - debug session
REM     Authors address  :  J.Hubb
REM                         Indigo skyline
REM                         A'DAAR channel
REM

:Begin
IF "%SU_DEBUG%" == "Y" ECHO ON
SET SU_VER=1.31

:ChkParams
IF "%1" == "" GOTO Help
IF "%1" == "/?" GOTO Help
FOR %%N IN (PromptStr Split Str2Env Ver) DO IF "%1" == "%%N" GOTO %1
GOTO FuncErr

REM
REM Function :  PromptStr
REM Desc.    :  Prompts a string and stores the text typed by the user to
REM             an environment variable
REM
REM Input    :  %2  prompt string with quotes
REM             %3  var. name to be set; it must be filled using as many
REM                 characters as max length
REM Output   :  environment variable named "%3"
REM
:PromptStr
    IF "%3" == "" GOTO ParamErr
    IF "%OS%" == "" GOTO PSWin9x
:PSWinNt
    CALL FileUtil NewFileName %TMP% SU tmp SU_PS_F1
    SET SU_PS_F2=%SU_PS_F1%2> %TMP%\%SU_PS_F1%2.tmp
    SET | GREP -i "^%3=" > %TMP%\%SU_PS_F1%.tmp
    ECHO.>> %TMP%\%SU_PS_F1%.tmp
    STRKEEP AFTER "%3=" /I < %TMP%\%SU_PS_F1%.tmp | STRLEN > %TMP%\%SU_PS_F2%.tmp
    SET /P SU_PS_L=<%TMP%\%SU_PS_F2%.tmp
    SET SU_PS_V=
    SET /P SU_PS_V=%2
    IF "%SU_PS_V%" == "" SET %3=
    IF "%SU_PS_V%" == "" GOTO PSWNSkip
    ECHO %SU_PS_V%| STRSUB 1 %SU_PS_L% > %TMP%\%SU_PS_F1%.tmp
    SET %3=
    SET /P %3=< %TMP%\%SU_PS_F1%.tmp
:PSWNSkip
    DEL %TMP%\%SU_PS_F1%.tmp
    DEL %TMP%\%SU_PS_F2%.tmp
    SET SU_PS_F1=
    SET SU_PS_F2=
    SET SU_PS_L=
    SET SU_PS_V=
    GOTO PSEnd
:PSWin9x
    STR2ENV %2 %3
:PSEnd
    GOTO EndSub

REM
REM Function :  Split
REM Desc.    :  Splits a string at the first occurrence of a specified
REM             separator char and returns first (CAR) and second (CDR) part
REM
REM Input    :  %2  separator character with quotes
REM             %3  string with quotes to be splitted at %2 occurrence
REM             %4  var. name to be set to CAR(%3) (see Lisp...)
REM             %5  var. name to be set to CDR(%3) (see Lisp...)
REM Output   :  environment variable named "%4" and "%5"
REM
:Split
    IF "%5" == "" GOTO ParamErr
    IF "%OS%" == "" GOTO SWin9x
:SWinNt
    SET SU_S_D=%2
    SET SU_S_D=%SU_S_D:~1,1%
    SET %4=
    SET %5=
    FOR /F "tokens=1 delims=%SU_S_D%" %%N IN (%3) DO SET %4=%%N
    FOR /F "tokens=1* delims=%SU_S_D%" %%N IN (%3) DO SET %5=%%O
    SET SU_S_D=
    GOTO SEnd
:SWin9x
    SET %4=%3
    SET %5=%3
    ECHO.| STRINS 1 %3 | STRINS 255 %2 | STRKEEP BEFORE %2 | STR2ENV "" %4 > NUL
    ECHO.| STRINS 1 %3 | STRKEEP AFTER %2 | STR2ENV "" %5 > NUL
:SEnd
    GOTO EndSub

REM
REM Function :  Str2Env
REM Desc.    :  Stores the first string of a text file to an environment
REM             variable
REM
REM Input    :  %2  pathname of the text file containing the string
REM             %3  var. name to be set; it must be filled using as many
REM                 characters as max length
REM Output   :  environment variable named "%3"
REM
:Str2Env
    IF "%3" == "" GOTO ParamErr
    IF "%OS%" == "" GOTO S2EWin9x
:S2EWinNt
    CALL FileUtil NewFileName %TMP% SU tmp SU_S2E_F1
    SET SU_S2E_F2=%SU_S2E_F1%2> %TMP%\%SU_S2E_F1%2.tmp
    SET | GREP -i "^%3=" > %TMP%\%SU_S2E_F1%.tmp
    ECHO.>> %TMP%\%SU_S2E_F1%.tmp
    STRKEEP AFTER "%3=" /I < %TMP%\%SU_S2E_F1%.tmp | STRLEN > %TMP%\%SU_S2E_F2%.tmp
    SET /P SU_S2E_L=<%TMP%\%SU_S2E_F2%.tmp
    STRSUB 1 %SU_S2E_L% < %2 > %TMP%\%SU_S2E_F1%.tmp
    SET %3=
    SET /P %3=< %TMP%\%SU_S2E_F1%.tmp
    DEL %TMP%\%SU_S2E_F1%.tmp
    DEL %TMP%\%SU_S2E_F2%.tmp
    SET SU_S2E_F1=
    SET SU_S2E_F2=
    SET SU_S2E_L=
    GOTO S2EEnd
:S2EWin9x
    CALL FileUtil NewFileName %TMP% SU tmp SU_S2E_F1
    COPY %2 %TMP%\%SU_S2E_F1%.tmp > NUL
    ECHO.>> %TMP%\%SU_S2E_F1%.tmp
    STR2ENV "" %3 < %TMP%\%SU_S2E_F1%.tmp > NUL
    DEL %TMP%\%SU_S2E_F1%.tmp
    SET SU_S2E_F1=
:S2EEnd
    GOTO EndSub

REM
REM Function :  Ver
REM Desc.    :  Sets the specified variable to StrUtil version number
REM
REM Input    :  %2  var. name to be set
REM Output   :  environment variable named "%2"
REM
:Ver
    IF "%2" == "" GOTO ParamErr
    SET %2=%SU_VER%
    GOTO EndSub

:FuncErr
ECHO.
ECHO StrUtil.bat %SU_VER%.
ECHO.
ECHO Error: function "%1" does not exist.
ECHO Execution aborted.
PAUSE > NUL
GOTO End

:ParamErr
ECHO.
ECHO StrUtil.bat %SU_VER%.
ECHO.
ECHO Error: function "%1" called with wrong parameter number (see Help):
ECHO        "%1", "%2", "%3", "%4", "%5", "%6", "%7", "%8", "%9"
ECHO Execution aborted.
PAUSE > NUL
GOTO End

:Help
ECHO.
ECHO StrUtil.bat %SU_VER%; Open Source library on November 24, 2007 by J.Hubb.
ECHO.
ECHO Syntax:
ECHO   STRUTIL {FunctionName} [FuncParam0 [FuncParam1 [...]]]
ECHO.
ECHO Calls the specified function {FunctionName} with optional
ECHO or requested parameters [FuncParam0], etc...
ECHO Defined functions are:
ECHO   PromptStr {PromptStr} {EnvVarName}
ECHO   Split     {Separator} {Str} {EnvVar1Name} {EnvVar2Name}
ECHO   Str2Env   {StrFileName} {EnvVarName}
ECHO   Ver       {EnvVarName}
ECHO.
GOTO End

:End
SET SU_VER=

:EndSub
IF "%DEBUG%" == "Y" ECHO ON
